SnipeSdk class
Constructors
- SnipeSdk()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCoinData(
String snipeId) → Future -
getStreaks(
String snipeId) → Future -
getTokenDetails(
String snipeId) → Future -
getTokenHistory(
String snipeId) → Future -
init(
String apiKey) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signUp(
String hash) → Future -
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
{required String eventId, required String snipeId, int? transactionAmount, int? partialPercentage, List< Map< ? debitTokens}) → FutureString, dynamic> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited